<?php

namespace SM\Service;

use SM\Factory\RelatorioCdaFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use SM\Service\ProcedureService;
use Zeedhi\Framework\Log\Console;

class RelatorioCdaService
{
    protected $RelatorioCdaFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;
    protected $ProcedureService;

    public function __construct(EntityManager $entityManager, RelatorioCdaFactory $RelatorioCdaFactory, Environment $Environment, NewCode $newCode, ProcedureService $ProcedureService)
    {
        $this->RelatorioCdaFactory          = $RelatorioCdaFactory;
        $this->connection                   = $entityManager->getConnection();
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
        $this->ProcedureService             = $ProcedureService;
    }

    public function getRelatorioCda($params): array
    {
        return $this->RelatorioCdaFactory->getRelatorioCda($params);
    }

    public function getFuncRelCda(): array
    {
        try {
            $nrorg = $this->Environment->getNrorg();
            return $this->RelatorioCdaFactory->getFuncRelCda(array(
                "NRORG" => $nrorg,
            ));
        } catch (\Error $error) {
            throw $error;
        }
    }

    public function getClienteRelCda($params): array
    {
        try {
            $nrorg = $this->Environment->getNrorg();

            return $this->RelatorioCdaFactory->getClienteRelCda(array(
                "NRORG" => $nrorg,
            ));
        } catch (\Error $error) {
            throw $error;
        }
    }

    public function getPropostaCdaRel($params): array
    {
        try {
            $nrorg = $this->Environment->getNrorg();
            $cdClient = isset($params['CDCLIENTE']) ? array_values($params['CDCLIENTE']) : null;

            return $this->RelatorioCdaFactory->getPropostaCdaRel(array(
                "NRORG" => $nrorg,
                "CDCLIENTE" => $cdClient,
            ));
        } catch (\Error $error) {
            throw $error;
        }
    }

    public function getProjetoCdaRel($params): array
    {
        try {
            $nrorg = $this->Environment->getNrorg();
            $nrProposFas = isset($params['NRPROPOSFAS']) ? array_values($params['NRPROPOSFAS']) : array();

            return $this->RelatorioCdaFactory->getProjetoCdaRel(array(
                "NRORG" => $nrorg,
                "NRPROPOSFAS" => $nrProposFas
            ));
        } catch (\Error $error) {
            throw $error;
        }
    }

    public function getTypeOfActivityCdaRel($params): array
    {
        try {
            $nrorg = $this->Environment->getNrorg();
            $nrProposFas = $params['NRPROPOSFAS'] ?? array();
            $cdClient = $params['CDCLIENTE'] ?? array();

            return $this->RelatorioCdaFactory->getTypeOfActivityCdaRel(array(
                "NRORG" => $nrorg,
                "CDCLIENTE" => $cdClient,
                "NRPROPOSFAS" => $nrProposFas
            ));
        } catch (\Error $error) {
            throw $error;
        }
    }
}
