<?php

namespace SM\Service;

use SM\Factory\Sm00011000ApuracaoFaturamentoFactory;
use SM\Util\Procedure\FctApurarFaturamentoLista;
use SM\Util\Procedure\FctCancApuracaoFaturamento;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class Sm00011000ApuracaoFaturamentoService
{
    protected $connection;
    protected $apuracaoFaturamentoFactory;
    protected $environment;
    protected $newCode;

    public function __construct(Sm00011000ApuracaoFaturamentoFactory $apuracaoFaturamentoFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager)
    {
        $this->apuracaoFaturamentoFactory   = $apuracaoFaturamentoFactory;
        $this->environment                  = $environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getApuracaoFaturamento($dynamicFilter)
    {
        if (isset($dynamicFilter["NRSEQCONTRATO"])) {
            $cont = $dynamicFilter["NRSEQCONTRATO"][0]["value"];
            $cont = '_' . implode('_', $cont) . "_";
            $params = array(
                "NRSEQCONTRATO" => $cont,
            );
            unset($dynamicFilter["NRSEQCONTRATO"]);
        } else {
            $params = array(
                "NRSEQCONTRATO" => null,
            );
        }

        return $this->apuracaoFaturamentoFactory->getApuracaoFaturamento($params, $dynamicFilter);
    }

    public function getFilialFatura()
    {
        return $this->apuracaoFaturamentoFactory->getFilialFatura();
    }

    public function getNrNotaFiscal($parametro)
    {
        return $this->apuracaoFaturamentoFactory->getNrNotaFiscal($parametro);
    }

    public function getItensDesmembramento($parametro)
    {
        return $this->apuracaoFaturamentoFactory->getItensDesmembramento($parametro);
    }

    public function getModalErroApuracaoFaturamento()
    {
        $dataParam = [
            "CDOPERADOR" => $this->environment->getCdOperador(),
        ];

        $data = $this->apuracaoFaturamentoFactory->getModalErroApuracaoFaturamento($dataParam);

        return $data;
    }

    public function getTabItensApuracaoFaturamento($parametro)
    {
        return $this->apuracaoFaturamentoFactory->getTabItensApuracaoFaturamento($parametro);
    }

    public function getTabDadosAgrupamentos($parametro)
    {
        return $this->apuracaoFaturamentoFactory->getTabDadosAgrupamentos($parametro);
    }

    public function validarAgrupamentoFat($params)
    {
        $nrorg = $this->environment->getNrOrg();
        $params = array(
            "NRSEQCONTRATO" => $params["NRSEQCONTRATO"],
            "NRPARCFATURA"  => $params["NRPARCFATURA"],
            "NRFATURACONT"  => $params["NRFATURACONT"],
            "DTINICIO"      => $params["DTINICIO"],
            "DTFIM"         => $params["DTFIM"],
            "NRORG"         => $nrorg
        );

        $resultado = $this->apuracaoFaturamentoFactory->validarAgrupamentoFat($params);

        return $resultado;
    }

    public function validarAgrupamentoFatMarcados($parametros)
    {
        $this->connection->beginTransaction();

        $erros = 0;
        $contratos = "";

        foreach ($parametros as $vencimentos) {
            $dataParam = array(
                "NRSEQCONTRATO" => "_" . $vencimentos["NRSEQCONTRATO"] . "_",
                "NRPARCFATURA"  => $vencimentos["NRPARCFATURA"],
                "NRFATURACONT"  => $vencimentos["NRFATURACONT"],
                "DTINICIO"      => $vencimentos["DTINICOMPET"],
                "DTFIM"         => $vencimentos["DTFINCOMPET"],
                "NRORG"         => $vencimentos["NRORG"]
            );
            $resultado = $this->apuracaoFaturamentoFactory->validarAgrupamentoFat($dataParam);
            if (count($resultado) > 0) {
                $erros = $erros + 1;
                foreach ($resultado as $dados) {
                    $contratos = $contratos . "- " . $dados['NRCONTRATOFCT'] . "<br>";
                }
            }
        }
        if ($erros == 0) {
            $contratos = "OK";
        }

        return $contratos;
    }

    public function gerarFaturamentoApuracao($params)
    {
        $nrfaturacont = $params["P_NRFATURACONT"];
        $nrrateioitemvenc = $params["P_NRRATEIOITEMFAT"];
        $nritfaturacont = $params["P_NRITFATURACONT"];
        $operador = $this->environment->getCdOperador();
        $nrorg = $this->environment->getNrOrg();
        $procedure = new FctApurarFaturamentoLista($this->connection);
        $procedure->executar($nrfaturacont, $nritfaturacont, $nrrateioitemvenc, $nrorg, $operador);
    }

    public function cancelarFaturamentoApuracao($params)
    {
        $nrseqcontrato    = $params["P_NRSEQCONTRATO"];
        $dataini          = $params["P_DATAINI"];
        $datafin          = $params["P_DATAFIN"];
        $nrfaturacont     = $params["P_NRFATURACONT"];
        $nrrateioitemvenc = $params["P_NRRATEIOITEMFAT"];
        $nritfaturacont   = $params["P_NRITFATURACONT"];
        $nrorg      = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        $procedure = new FctCancApuracaoFaturamento($this->connection);
        $procedure->executar($nrorg, $nrseqcontrato, $cdoperador, $dataini, $datafin, $nrfaturacont, $nrrateioitemvenc, $nritfaturacont);
    }

    public function alterarDataSaidaDaNotaFiscal($params)
    {
        $data = $params["DATA"];
        $nrorg      = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        foreach ($params['NF'] as $nf) {
            $notas = explode(', ', $nf["NRLANCTONF"]);
            foreach ($notas as $notaFiscal) {
                $params = array(
                    "IDSTATUS"     => "D",
                    "DTENTRSAID"   => $data,
                    "CDOPERULTATU" => $cdoperador,
                    "CDFILIAL"     => $nf["CDFILIALNF"],
                    "NRLANCTONF"   => $notaFiscal,
                    "NRORG"        => $nrorg
                );
                $this->apuracaoFaturamentoFactory->alterarDataSaidaDaNotaFiscal($params);
            }
        }
    }

    public function alterarStatusParcelasZeradas($params)
    {
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        $params = array(
            "NRFATURACONT" => $params["NRFATURACONT"],
            "IDSITUACAO"   => $params["IDSITUACAO"],
            "CDOPERULTATU" => $cdoperador,
            "NRORG"        => $nrorg
        );

        $this->apuracaoFaturamentoFactory->alterarSituacaoParcela($params);
        $this->apuracaoFaturamentoFactory->alterarSituacaoItens($params);
    }

    public function anularApuracao($params)
    {
        $this->connection->beginTransaction();
        try {
            $dsJustificativa = $params["DSJUSTIFICATIVA"];
            $nrorg = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();

            $dataParam = array(
                "NRFATURACONT"  => $params["NRFATURACONT"],
                "NRORG"         => $nrorg,
            );

            $dataset = $this->apuracaoFaturamentoFactory->getJustificativa($dataParam);
            $justificativaAtual = $dataset["data"][0]["DSJUSTIFICATIVA"];

            if (empty($justificativaAtual)) {
                $novaJustificativa = $dsJustificativa;
            }

            $novaJustificativa = $dsJustificativa . "\n" . $justificativaAtual;

            $params = array(
                "DSJUSTIFICATIVA"       => $novaJustificativa,
                "NRFATURACONT"          => $params["NRFATURACONT"],
                "NRORG"                 => $nrorg,
                "CDOPERADOR"            => $cdoperador,
                "NRJUSTIFCANCELAAPUR"   => $params['NRJUSTIFCANCELAAPUR'],
            );

            $this->apuracaoFaturamentoFactory->anularApuracao($params);
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function getjustificativaCancelamento()
    {
        return $this->apuracaoFaturamentoFactory->getjustificativaCancelamento();
    }

    public function invoiceValidateHasAlreadyBeenUsed($params)
    {

        $nrLanctoNF = $params["nrlanctonf"];
        $cdFilial = $params["cdfilial"];
        $data = $this->apuracaoFaturamentoFactory->invoiceValidateHasAlreadyBeenUsed($nrLanctoNF, $cdFilial);
        return $data;
    }

    public function fatuManual($params)
    {
        $cdoperador = $this->environment->getCdOperador();
        $nrorg = $this->environment->getNrOrg();
        $novoCodigo = $this->newCode->getCodeByTableName("FCT_APURACAO", $nrorg, 1, 10, true);
        $paramsApuManual = array(
            "NRAPURACAO"       => $novoCodigo,
            "NRSEQCONTRATO"    => null,
            "NRPARCFATURA"     => $params["NRPARCFATURA"],
            "NRGRUPOFATURA"    => null,
            "CDEMPRESA"        => $params["CDEMPRESA"],
            "CDFILIAL"         => $params["CDFILIAL"],
            "NRLANCTONF"       => $params["NRLANCTONF"],
            "VRNOTAFISC"       => $params["VRNOTAFISC"],
            "VRVENCIMENTO"     => $params["VRVENCIMENTO"],
            "NRORG"            => $nrorg,
            "CDOPERADOR"       => $cdoperador
        );

        $this->apuracaoFaturamentoFactory->criaApuracaoManual($paramsApuManual);

        $this->inserirRelacApuracaoFatura($params, $nrorg, $cdoperador, $novoCodigo);

        $paramsJustificativa = array(
            "NRFATURACONT"  => $params["NRFATURACONT"],
            "NRORG"         => $nrorg
        );
        $dataset = $this->apuracaoFaturamentoFactory->getJustificativa($paramsJustificativa);
        $justificativaAtual = $dataset["data"][0]["DSJUSTIFICATIVA"];
        $justificativa = $params["DSJUSTIFICATIVA"];

        if (empty($justificativaAtual)) {
            $novaJustificativa = $justificativa;
        } else {
            $novaJustificativa = $justificativa . "\n" . $justificativaAtual;
        }

        $params = array(
            "NRAPURACAO"       => null,
            "DSJUSTIFICATIVA"  => $novaJustificativa,
            "VRNOTAFISC"       => $params["VRNOTAFISC"],
            "NRFATURACONT"     => $params["NRFATURACONT"],
            "NRORG"            => $nrorg,
            "CDOPERADOR"       => $cdoperador
        );

        $this->apuracaoFaturamentoFactory->atualizaParcelaApuracaoManual($params);
    }

    public function inserirRelacApuracaoFatura($params, $nrorg, $cdoperador, $novoCodigo)
    {
        $nrapurfatura = $this->newCode->getCodeByTableName("FCT_RELACAPURACAOFATURA", $nrorg, 1, 10, true);
        $params = array(
            "NRAPURACAOFATURA" => $nrapurfatura,
            "NRAPURACAO"       => $novoCodigo,
            "NRFATURACONT"     => $params["NRFATURACONT"],
            "NRORG"            => $nrorg,
            "CDOPERADOR"       => $cdoperador
        );
        $this->apuracaoFaturamentoFactory->inserirRelacApuracaoFatura($params);
    }

    public function validaQtItens($params)
    {
        $nrorg = $this->environment->getNrOrg();
        $params = array(
            "NRFATURACONT"     => $params["NRFATURACONT"],
            "NRORG"            => $nrorg,
        );

        $dataset = $this->apuracaoFaturamentoFactory->validaQtItens($params);
        if ($dataset[0]["VALIDA"] > 1) {
            return "OK";
        }
        return "ERRO";
    }

    public function desmembrarParcela($params)
    {
        $this->connection->beginTransaction();
        $operador = $this->environment->getCdOperador();
        $nrorg = $this->environment->getNrOrg();
        $dsJustificativa = $params["DSJUSTIFICATIVA"];
        $itDesmembramento = $params["ITDESMEMBRAMENTO"];
        $nrfaturacont = $params["NRFATURACONT"];
        $idFormaDesmembramento = $params["IDFORMADESMEMBAMENTO"];
        try {
            $novoNrFaturaCont = null;
            $params = array(
                "NRFATURACONT"     => $params["NRFATURACONT"],
                "NRORG"            => $nrorg
            );
            $dadosParcela = $this->apuracaoFaturamentoFactory->getDadosParcela($params);
            $dadosParcela = (count($dadosParcela["data"]) > 0) ? $dadosParcela["data"][0] : null;
            if ($dadosParcela != null) {
                $justificativaAtual = $dadosParcela["DSJUSTIFICATIVA"];
                $novaJustificativa  = $dsJustificativa . ((empty($justificativaAtual)) ? "" : "\n" . $justificativaAtual);
                foreach ($itDesmembramento as $item) {
                    $params = array(
                        "NRITFATURACONT"   => $item,
                        "NRFATURACONT"     => $nrfaturacont,
                        "NRORG"            => $nrorg,
                    );

                    $dadosItem = $this->apuracaoFaturamentoFactory->getDadosItem($params);
                    $dadosItem = (count($dadosItem["data"]) > 0) ? $dadosItem["data"][0] : null;
                    if ($dadosItem != null) {
                        $idAcao = $idFormaDesmembramento == '1' ? "DESAGRUPA" : "AGRUPA";
                        /*Gerar uma parcela para cada item selecionado*/
                        if ($idFormaDesmembramento == '1' || $novoNrFaturaCont == null) {
                            /* 1 -  Insere a Parcela*/
                            $dadosParcela["VRVENCIMENTO"] = $dadosItem["VRVENCIMENTO"];
                            $novoNrFaturaCont = $this->inserirParcela($dadosParcela, $dadosItem["NRSEQCONTRATO"], $nrorg, $operador, $novaJustificativa);
                            $this->inserirRelacAgrupContFat($dadosItem["NRSEQCONTRATO"], $novoNrFaturaCont, $nrorg, $operador, $idAcao, $dadosParcela["NRMEDICAOFATURA"]);
                            //$this->alterarRelacContratosFatura($nrfaturacont, $dadosItem["NRSEQCONTRATO"], "DESAGRUPA", $nrorg, $operador, $novoNrFaturaCont);
                            /* 2 - Insere o Item */
                            $this->inserirItemParcela(array($dadosItem), $nrfaturacont, $nrorg, $novoNrFaturaCont, $operador, $novaJustificativa);
                        } else {
                            /*1 - Insere o novo item*/
                            $this->inserirItemParcela(array($dadosItem), $nrfaturacont, $nrorg, $novoNrFaturaCont, $operador, $novaJustificativa);
                            $this->inserirRelacAgrupContFat($dadosItem["NRSEQCONTRATO"], $novoNrFaturaCont, $nrorg, $operador, $idAcao, $dadosParcela["NRMEDICAOFATURA"]);

                            /* 2 - Atualiza o valor da nova parcela criada */
                            $params = array(
                                "VRVENCIMENTO" => $dadosItem["VRVENCIMENTO"],
                                "NRFATURACONT" => $novoNrFaturaCont,
                                "NRORG"        => $nrorg
                            );

                            $this->apuracaoFaturamentoFactory->atualizaValorParcelaNova($params);
                        }

                        /* Deleta o item da parcela de Origem */
                        $params = array(
                            "NRITFATURACONT"   => $item,
                            "NRFATURACONT"     => $nrfaturacont,
                            "NRSEQCONTRATO"    => $dadosItem["NRSEQCONTRATO"],
                            "NRORG"            => $nrorg
                        );
                        $this->apuracaoFaturamentoFactory->deletaItemParcelaOrigem($params);

                        /* Atualiza a parcela de origem */
                        $params = array(
                            "VRVENCIMENTO"     => $dadosItem["VRVENCIMENTO"],
                            "DSJUSTIFICATIVA"  => $novaJustificativa,
                            "NRFATURACONT"     => $nrfaturacont,
                            "NRORG"            => $nrorg
                        );
                        $this->apuracaoFaturamentoFactory->atualizaValorParcelaOrigem($params);
                    }
                }
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function inserirParcela($dadosParcela, $contrato, $nrorg, $operador, $dsJustificativa)
    {
        $newnrfaturacont = $this->newCode->getCodeByTableName("FCT_FATURACONT", $nrorg, 1, 10, true);

        $nrparcela = null;
        if (!empty($contrato)) {
            $params = array(
                "NRSEQCONTRATO" => $contrato,
                "NRORG"         => $nrorg
            );
            $dataset = $this->apuracaoFaturamentoFactory->getQuantidadeParcelasContrato($params);
            $nrparcela = (int)$dataset["data"][0]["CONTADOR"] + 1;
        }

        $params = array(
            "NRFATURACONT"       => $newnrfaturacont,
            "NRSEQCONTRATO"      => null, //$contrato,
            "NRGRUPOFATURA"      => $dadosParcela["NRGRUPOFATURA"],
            "CDFILIALFATURA"     => $dadosParcela["CDFILIALFATURA"],
            "NRPARCFATURA"       => $dadosParcela["NRPARCFATURA"],
            "IDTPFATURA"         => $dadosParcela["IDTPFATURA"],
            "IDSITUACAO"         => $dadosParcela["IDSITUACAO"],
            "DTINICOMPET"        => $dadosParcela["DTINICOMPET"],
            "DTFINCOMPET"        => $dadosParcela["DTFINCOMPET"],
            "DTLIMITEAPU"        => $dadosParcela["DTLIMITEAPU"],
            "DTVENCIMENTO"       => $dadosParcela["DTVENCIMENTO"],
            "NRDIASVENCIMENTO"   => $dadosParcela["NRDIASVENCIMENTO"],
            "QTDIASFATUVENC"     => $dadosParcela["QTDIASFATUVENC"],
            "VRVENCIMENTO"       => $dadosParcela["VRVENCIMENTO"],
            "VRFALTAFATURAR"     => $dadosParcela["VRVENCIMENTO"],
            "IDFORMAFATURA"      => $dadosParcela["IDFORMAFATURA"],
            "DSJUSTIFICATIVA"    => $dsJustificativa,
            "NRAPURACAO"         => $dadosParcela["NRAPURACAO"],
            "NRMEDICAOFATURA"    => $dadosParcela["NRMEDICAOFATURA"],
            "CDTIPOOPERFATURA"   => $dadosParcela["CDTIPOOPERFATURA"],
            "CDSERIENF"          => $dadosParcela["CDSERIENF"],
            "CDEMPRESA"          => $dadosParcela["CDEMPRESA"],
            "CDINSCESTA"         => $dadosParcela["CDINSCESTA"],
            "CDINSCMUNI"         => $dadosParcela["CDINSCMUNI"],
            "VRFATURADO"         => 0,
            "NRORG"              => $nrorg,
            "OPERADOR"           => $operador,
            "NRPARCELA"          => $nrparcela
        );
        $this->apuracaoFaturamentoFactory->insereParcelaDesmembramento($params);

        return $newnrfaturacont;
    }

    public function inserirRelacAgrupContFat($nrseqcontrato, $nrfaturacont, $nrorg, $operador, $idAcao, $nrmedicaofatura)
    {
        $nragrupcontfat = $this->newCode->getCodeByTableName("FCT_RELACAGRUPCONTFAT", $nrorg, 1, 10, true);
        $params = array(
            "NRAGRUPCONTFAT"  => $nragrupcontfat,
            "NRSEQCONTRATO"   => $nrseqcontrato,
            "NRORG"           => $nrorg,
            "OPERADOR"        => $operador,
            "NRFATURACONT"    => $nrfaturacont,
            "IDPARCAGRUP"     => ($idAcao == "AGRUPA") ? "S" : "N",
            "NRMEDICAOFATURA" => $nrmedicaofatura
        );
        $this->apuracaoFaturamentoFactory->salvarRelacAgrupContFat($params);
    }

    public function inserirItemParcela($itensFat, $nrfaturaconts, $nrorg, $newnrfaturacont, $operador, $dsJustificativa)
    {
        if ($itensFat == null) {
            $params = array(
                "NRORG"         => $nrorg,
                "NRSEQCONTRATO" => null
            );
            $itensFat = $this->apuracaoFaturamentoFactory->getItemsFatura($params, $nrfaturaconts);
        }

        foreach ($itensFat as $itemFat) {
            $novoNrFaturaItCont = $this->newCode->getCodeByTableName("FCT_ITFATURACONT", $nrorg, 1, 10, true);
            $params = array(
                "NRITFATURACONT"     => $novoNrFaturaItCont,
                "NRFATURACONT"       => $newnrfaturacont,
                "NRSEQCONTRATO"      => $itemFat["NRSEQCONTRATO"],
                "NRITEMOCONTRATO"    => $itemFat["NRITEMOCONTRATO"],
                "CDPRODFATURA"       => $itemFat["CDPRODFATURA"],
                "IDSITUACAO"         => $itemFat["IDSITUACAO"],
                "VRVENCIMENTO"       => $itemFat["VRVENCIMENTO"],
                "VRFALTAFATURAR"     => $itemFat["VRVENCIMENTO"],
                "IDFORMAFATURA"      => $itemFat["IDFORMAFATURA"],
                "NRAPURACAO"         => $itemFat["NRAPURACAO"],
                "DSJUSTIFICATIVA"    => $dsJustificativa,
                "VRFATURADO"         => 0,
                "NRORG"              => $nrorg,
                "OPERADOR"           => $operador
            );

            $this->apuracaoFaturamentoFactory->insereItemDesmembramento($params);
        }
    }

    public function desagruparParcelasFaturamento($params)
    {
        $this->connection->beginTransaction();
        $nrfaturacont = $params["NRFATURACONT"];
        $nrseqcontratos = $params["NRSEQCONTRATO"];
        $idAcao = $params["IDACAO"];
        $operador = $this->environment->getCdOperador();
        $nrorg = $this->environment->getNrOrg();
        try {
            $params = array(
                "NRFATURACONT" => $nrfaturacont,
                "NRORG"        => $nrorg
            );
            $dadosParcela = $this->apuracaoFaturamentoFactory->getDadosParcela($params);
            if (!isset($dadosParcela)) {
                throw new \Exception("ERRO");
            } else {
                $vrvencimentoold = 0;
                $dadosParcela    = $dadosParcela["data"][0];
                foreach ($nrseqcontratos as $nrseqcontrato) {
                    $vrTotalParcela = 0;
                    $params = array(
                        "NRORG"         => $nrorg,
                        "NRSEQCONTRATO" => $nrseqcontrato
                    );

                    $dadosItem = $this->apuracaoFaturamentoFactory->getItemsFatura($params, $nrfaturacont);

                    foreach ($dadosItem["data"] as $dadoItem) {
                        $vrTotalParcela = $vrTotalParcela + $dadoItem["VRVENCIMENTO"];
                    }

                    $dadosParcela["VRVENCIMENTO"] = $vrTotalParcela;
                    $vrvencimentoold = $vrvencimentoold + $vrTotalParcela;
                    $newnrfaturacont = $this->inserirParcela($dadosParcela, $nrseqcontrato, $nrorg, $operador, null);
                    $this->alterarRelacContratosFatura($nrfaturacont, $nrseqcontrato, $idAcao, $nrorg, $operador, $newnrfaturacont);

                    foreach ($dadosItem["data"] as $dadoItem) {
                        $this->inserirItensFatura($dadoItem, $nrseqcontrato, $newnrfaturacont, null, $nrorg, $operador);
                    }
                }

                $this->validarQuantidadeContratosParcela($nrfaturacont, $nrorg, $operador, $vrvencimentoold, $nrseqcontratos);
                $this->connection->commit();
            }
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function inserirItensFatura($dadosItem, $contrato, $newnrfaturacont, $dsJustificativa, $nrorg, $operador)
    {
        $newnrfaturaitem = $this->newCode->getCodeByTableName("FCT_ITFATURACONT", $nrorg, 1, 10, true);
        $params = array(
            "NRITFATURACONT"     => $newnrfaturaitem,
            "NRFATURACONT"       => $newnrfaturacont,
            "NRSEQCONTRATO"      => $contrato,
            "DSJUSTIFICATIVA"    => $dsJustificativa,
            "VRFATURADO"         => 0,
            "NRITEMOCONTRATO"    => $dadosItem["NRITEMOCONTRATO"],
            "CDPRODFATURA"       => $dadosItem["CDPRODFATURA"],
            "IDSITUACAO"         => $dadosItem["IDSITUACAO"],
            "VRVENCIMENTO"       => $dadosItem["VRVENCIMENTO"],
            "VRFALTAFATURAR"     => $dadosItem["VRVENCIMENTO"],
            "IDFORMAFATURA"      => $dadosItem["IDFORMAFATURA"],
            "NRAPURACAO"         => $dadosItem["NRAPURACAO"],
            "NRORG"              => $nrorg,
            "OPERADOR"           => $operador
        );

        $this->apuracaoFaturamentoFactory->insereItemDesmembramento($params);
    }

    public function validarQuantidadeContratosParcela($nrfaturacont, $nrorg, $operador, $vrvencimentoold, $nrseqcontratos)
    {
        $params = array(
            "NRSEQCONTRATO" => null,
            "NRORG"         => $nrorg
        );
        $relacParcelas = $this->apuracaoFaturamentoFactory->getInformacoesRelacParcelaCont($nrfaturacont, $params);
        if (count($relacParcelas) == 0) {
            $this->apuracaoFaturamentoFactory->deletarParcelaFatura($nrfaturacont, $nrorg);
        } else {
            if (count($relacParcelas) == 1) {
                $params = array(
                    "NRFATURACONT" => $nrfaturacont,
                    "NRORG"        => $nrorg,
                    "CDOPERADOR"   => $operador
                );
                $this->apuracaoFaturamentoFactory->alterarInfoAgrupamentoParcela($params);
            }

            $params = array(
                "NRFATURACONT"    => $nrfaturacont,
                "NRORG"           => $nrorg,
                "VRVENCIMENTO"    => $vrvencimentoold,
                "DSJUSTIFICATIVA" => null
            );
            $this->apuracaoFaturamentoFactory->atualizaValorParcelaOrigem($params);
        }

        foreach ($nrseqcontratos as $nrseqcontrato) {
            $params = array(
                "NRITFATURACONT"   => null,
                "NRFATURACONT"     => $nrfaturacont,
                "NRSEQCONTRATO"    => $nrseqcontrato,
                "NRORG"            => $nrorg
            );

            $this->apuracaoFaturamentoFactory->DeletaItemParcelaOrigem($params);
        }
    }

    public function alterarRelacContratosFatura($nrfaturaconts, $nrseqcontrato, $idAcao, $nrorg, $operador, $newnrfaturacont)
    {
        try {
            $paramsRelac = array(
                "NRSEQCONTRATO" => $nrseqcontrato,
                "NRORG"         => $nrorg
            );
            $relacParcelas = $this->apuracaoFaturamentoFactory->getInformacoesRelacParcelaCont($nrfaturaconts, $paramsRelac);
            foreach ($relacParcelas["data"] as $relacParcela) {
                $this->inserirRelacAgrupContFat($relacParcela["NRSEQCONTRATO"], $newnrfaturacont, $nrorg, $operador, $idAcao, $relacParcela["NRMEDICAOFATURA"]);
            }

            $this->apuracaoFaturamentoFactory->deletarRelacAgrupamentoContFat($nrfaturaconts, $paramsRelac);
        } catch (\Exception $e) {
            throw $e;
        }
    }
}
