import { dayjs, IEventParam, Metadata } from '@zeedhi/core';
import { Button, SelectMultiple } from '@zeedhi/common';
import { TekGrid, TekRestDatasource } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class SmRelatorioCDAController {
    public currentRow: any = {};

    private getGridInstance() {
        return Metadata.getInstance<TekGrid>('tek_grid_relatorio_customizavel_cda');
    }

    private getFilterInputs(field: string): any {
        return this.getGridInstance().getFilterInputs(field);
    }
   
    public openFilter({ component }: any) {
        const filterButton = Metadata.getInstance<Button>(
            `${component.name}_filterButton`,
        );
        filterButton.click({} as Event, {} as HTMLElement);
    }

    public onChangeDateFilterField() {
        const clientFilterGrid = this.getFilterInputs('CDCLIENTE');
        const proposalFilterGrid = this.getFilterInputs('NRPROPOSFAS');
        const dateFilterGrid = this.getFilterInputs('DTSERVPRESTCDAREL');
        const typeOfActivityFilterGrid = this.getFilterInputs('CDTIPOSERV');

        const clientInstance = Metadata.getInstance<SelectMultiple>(clientFilterGrid[0].name);
        const proposalInstance = Metadata.getInstance<SelectMultiple>(proposalFilterGrid[0].name);
        const typeOfActivityInstance = Metadata.getInstance<SelectMultiple>(typeOfActivityFilterGrid[0].name);

        if (dateFilterGrid[0].value) {
            clientInstance.datasource.setFilter({
                DTSERVPREST: dateFilterGrid[0].value,
            });

            proposalInstance.datasource.setFilter({
                DTSERVPREST: dateFilterGrid[0].value,
            });

            typeOfActivityInstance.datasource.setFilter({
                DTSERVPREST: dateFilterGrid[0].value,
            });
        }
    }

    public onChangeClientFilterField() {
        const clientFilterGrid = this.getFilterInputs('CDCLIENTE');
        const proposalFilterGrid = this.getFilterInputs('NRPROPOSFAS');
        const typeOfActivityFilterGrid = this.getFilterInputs('CDTIPOSERV');

        const proposalInstance = Metadata.getInstance<SelectMultiple>(proposalFilterGrid[0].name);
        const typeOfActivityInstance = Metadata.getInstance<SelectMultiple>(typeOfActivityFilterGrid[0].name);

        if (clientFilterGrid[0].isValid() && clientFilterGrid[0].value.length !== 0) {
            proposalInstance.datasource.setFilter({
                CDCLIENTE: clientFilterGrid[0].value,
            });

            typeOfActivityInstance.datasource.setFilter({
                CDCLIENTE: clientFilterGrid[0].value,
            });
        } else {
            proposalInstance.datasource.setFilter({
            });

            typeOfActivityInstance.datasource.setFilter({
            });
        }
    }

    public onChangeProposalFilterField() {
        const clientFilterGrid = this.getFilterInputs('CDCLIENTE');
        const projectFilterGrid = this.getFilterInputs('CDPROJETO');
        const proposalFilterGrid = this.getFilterInputs('NRPROPOSFAS');
        const typeOfActivityFilterGrid = this.getFilterInputs('CDTIPOSERV');

        const projectInstance = Metadata.getInstance<SelectMultiple>(projectFilterGrid[0].name);
        const typeOfActivityInstance = Metadata.getInstance<SelectMultiple>(typeOfActivityFilterGrid[0].name);

        if (proposalFilterGrid[0].isValid() && proposalFilterGrid[0].value.length !== 0) {
            projectInstance.datasource.setFilter({
                NRPROPOSFAS: proposalFilterGrid[0].value,
            });
            typeOfActivityInstance.datasource.setFilter({
                CDCLIENTE: clientFilterGrid[0].value,
                NRPROPOSFAS: proposalFilterGrid[0].value,
            });
        } else {
            projectInstance.datasource.setFilter({
            });
            typeOfActivityInstance.datasource.setFilter({
                CDCLIENTE: clientFilterGrid[0].value,
            });
        }
    }

    public gerarRelatorioRelacCDA() {
        const grid = (Metadata.getInstance<TekGrid>('tek_grid_relatorio_customizavel_cda').datasource as TekRestDatasource).dynamicFilter;
        const cliente = (grid.CDCLIENTE !== undefined) ? Utilities.formatarArrayParaString(grid.CDCLIENTE[0].value) : 'T';
        const projeto = (grid.CDPROJETO !== undefined) ? Utilities.formatarArrayParaString(grid.CDPROJETO[0].value) : 'T';
        const func = (grid.CDOPERADORCDAREL !== undefined) ? Utilities.formatarArrayParaString(grid.CDOPERADORCDAREL[0].value) : 'T';
        const tipoServ = (grid.CDTIPOSERV !== undefined) ? Utilities.formatarArrayParaString(grid.CDTIPOSERV[0].value) : 'T';
        const proposta = (grid.NRPROPOSFAS !== undefined) ? Utilities.formatarArrayParaString(grid.NRPROPOSFAS[0].value) : 'T';
    
        Utilities.openReport('/geraBirtReport', {
            P_CDCLIENTE: cliente,
            P_CDCLIENTE_T: cliente,
            P_DTINI: grid.DTSERVPRESTCDAREL[0].value[0],
            P_DTFIM: (grid.DTSERVPRESTCDAREL[0].value[1] !== undefined) ? grid.DTSERVPRESTCDAREL[0].value[1] : grid.DTSERVPRESTCDAREL[0].value[0],
            P_CDPROJETO: projeto,
            P_CDTIPOSERV: tipoServ,
            P_NRPROPOSTA: proposta,
            P_CDFUNC: func,
            P_CDPROJETO_T: projeto,
            P_CDTIPOSERV_T: tipoServ,
            P_NRPROPOSTA_T: proposta,
            P_CDFUNC_T: func,
            P_NRORG: '20',
            __report_name: 'Relacao_de_Controles_de_Atividades',
            isUrl: true,
        });
    }

    public calcSummary({ summary, rowValue, columnName }: IEventParam<TekGrid>): void {
        const minutesToHour = (minutes: number) => {
            const hours = Math.floor(Math.trunc(minutes) / 60).toString();
            const minutesLeft = `0${Math.trunc(minutes) % 60}`.substr(-2);
            return `${hours}:${minutesLeft}`;
        };
      
        const hourToMinutes = (hour: string) => {
            const hourParts = (hour || '0:00').split(':');
            return parseInt(hourParts[0], 10) * 60 + parseInt(hourParts[1], 10);
        };
      
        const toDate = (date: string) => dayjs(date, 'DD/MM/YYYY');
      
        switch (columnName) {
            case 'date_1':
                // Agrupamento do tipo COUNT não precisa ser feito nada
                break;

            case 'DTENTRADACDAREL':
                // SUM
                summary.sum = minutesToHour(hourToMinutes(summary.sum) + hourToMinutes(rowValue));
                break;
                
            case 'HRAUSENCIAALMOCOCDAREL':
                // SUM
                summary.sum = minutesToHour(hourToMinutes(summary.sum) + hourToMinutes(rowValue));
                break;
      
            case 'DTSAIDACDAREL':
                // SUM
                summary.sum = minutesToHour(hourToMinutes(summary.sum) + hourToMinutes(rowValue));
                break;
          
            case 'QTHRTOTALCDAREL':
                // SUM
                summary.sum = minutesToHour(hourToMinutes(summary.sum) + hourToMinutes(rowValue));
                break;
          
            case 'QTHRDESLOCAMENTOFATCDAREL':
                // SUM
                summary.sum = minutesToHour(hourToMinutes(summary.sum) + hourToMinutes(rowValue));
                break;

            case 'QTHRATIVIDADEFATCDAREL':
                // SUM
                summary.sum = minutesToHour(hourToMinutes(summary.sum) + hourToMinutes(rowValue));
                break;
               
            case 'DSJUSTHRNAOFATURADACDAREL':
                // SUM
                summary.sum = minutesToHour(hourToMinutes(summary.sum) + hourToMinutes(rowValue));
                break;

            case 'hour_2':
                // AVG
                summary.sum = minutesToHour(hourToMinutes(summary.sum) + hourToMinutes(rowValue));
                summary.avg = minutesToHour(hourToMinutes(summary.sum) / summary.count);
                break;
      
            case 'date_2': // MIN
                summary.min = summary.min === undefined || toDate(summary.min) > toDate(rowValue) ? rowValue : summary.min;
                break;
        
            case 'string_1': // MAX
                summary.max = summary.max === undefined || summary.max < rowValue ? rowValue : summary.max;
                break;
        
            default:
                break;
        }
    }
}
